@@ -3,9 +3,9 @@
 
 from django.conf import settings
 
-from .models import REGISTRY
+from .models import Preflight, register  # NOQA
 
-__version__ = "0.1.4"
+__version__ = "0.1.5"
 
 
 def autodiscover():
@@ -18,16 +18,3 @@ def autodiscover():
             msg = e.args[0].lower()
             if 'no module named' not in msg or 'preflight' not in msg:
                 raise
-
-
-class Preflight(object):
-
-    name = "Application Checks"
-
-    def authenticate(self, request):
-        return request.user.is_staff
-
-
-def register(class_):
-    if class_ not in REGISTRY:
-        REGISTRY.append(class_)
